import sys
from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

install_requires = ['werkzeug']
if sys.version_info < (2, 7):
    install_requires.append("argparse == 1.2.1")

setup(name='repyt',
      version='0.1.1',
      description='Automatically re-run Python applications when files change.',
      long_description=readme(),
      url='https://github.com/di/repyt',
      author='Dustin Ingram',
      author_email='di@wiota.co',
      keywords='console command-line development re-run reload testing tests',
      entry_points = {
            'console_scripts': ['repyt = repyt.repyt:main']
      },
      license='MIT',
      packages=['repyt'],
      install_requires=install_requires,
      classifiers=[
            'Development Status :: 4 - Beta',
            'Environment :: Console',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: BSD License',
            'Natural Language :: English',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: MacOS :: MacOS X',
            'Operating System :: POSIX :: Linux',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2',
            'Programming Language :: Python :: 2.6',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.0',
            'Programming Language :: Python :: 3.1',
            'Programming Language :: Python :: 3.2',
            'Programming Language :: Python :: 3.3',
            'Programming Language :: Python :: 3.4',
            'Topic :: Utilities'
        ],
      zip_safe=False)



import os
import pwd
import sys
import argparse
import subprocess

try:
    # Location of run_with_reloader in the latest version of Werkzeug
    from werkzeug._reloader import run_with_reloader
except ImportError:
    # Old location of run_with_reloader
    from werkzeug.serving import run_with_reloader


def get_command():
    '''
    Return the command from the args supplied.
    '''
    parser = argparse.ArgumentParser(
        description='Automatically re-run Python commands when files change.')

    parser.add_argument(
        '--command',
        '-c',
        action='store',
        default=None,
        help='Specify any other shell command as a single string.')
    parser.add_argument(
        "args",
        nargs=argparse.REMAINDER,
        help='Arguments as if you were passing them to the `python` command.')

    op = parser.parse_args(sys.argv[1:])

    if op.command:
        return op.command
    elif op.args:
        return "python %s" % (" ".join(op.args))
    else:
        parser.print_usage()
        sys.stderr.write('repyt: error: too few arguments.\n')
        sys.exit(2)


def get_shell():
    '''
    Return the current shell.
    '''
    return os.environ.get('SHELL', pwd.getpwuid(os.getuid()).pw_shell)


def get_files():
    '''
    Get the files to monitor.
    '''
    matches = []
    for root, dirnames, filenames in os.walk('.'):
        for filename in filenames:
            matches.append(os.path.join(root, filename))
    return matches


def main():
    # Command-line entry point for setup.py install/develop
    command = get_command()
    shell = get_shell()
    files = get_files()

    run_with_reloader(
        lambda: subprocess.call(
            command,
            shell=True,
            executable=shell),
        extra_files=files)
